@@ -2,11 +2,11 @@
 **  Copyright (c) 2006, 2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: config.c,v 1.2 2007/03/05 20:52:53 msk Exp $
+**  $Id: config.c,v 1.3 2007/04/21 18:33:27 msk Exp $
 */
 
 #ifndef lint
-static char config_c_id[] = "@(#)$Id: config.c,v 1.2 2007/03/05 20:52:53 msk Exp $";
+static char config_c_id[] = "@(#)$Id: config.c,v 1.3 2007/04/21 18:33:27 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -63,12 +63,12 @@ struct config *
 config_load(FILE *in, struct configdef *def, unsigned int *line)
 {
 	int arg;
-	int n;
+	int n = -1;
 	int err = 0;
 	unsigned int myline = 0;
-	unsigned int value;
+	unsigned int value = -1;
 	char *p;
-	char *str;
+	char *str = NULL;
 	struct config *new;
 	struct config *cur = NULL;
 	char buf[BUFRSZ + 1];
@@ -154,6 +154,8 @@ config_load(FILE *in, struct configdef *def, unsigned int *line)
 
 				  default:
 					assert(0);
+					/* NOTREACHED */
+					return NULL;
 				}
 			}
 
