@@ -1,15 +1,15 @@
 /*
-**  Copyright (c) 2006 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2006, 2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: config.h,v 1.1 2006/04/16 23:40:59 msk Exp $
+**  $Id: config.h,v 1.2 2007/03/05 20:52:53 msk Exp $
 */
 
 #ifndef _CONFIG_H_
 #define _CONFIG_H_
 
 #ifndef lint
-static char config_h_id[] = "@(#)$Id: config.h,v 1.1 2006/04/16 23:40:59 msk Exp $";
+static char config_h_id[] = "@(#)$Id: config.h,v 1.2 2007/03/05 20:52:53 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -41,7 +41,7 @@ struct configdef
 /* prototypes */
 extern char *config_check __P((struct config *, struct configdef *));
 extern void config_free __P((struct config *));
-extern int config_get __P((struct config *, char *, void *));
+extern int config_get __P((struct config *, const char *, void *));
 extern struct config *config_load __P((FILE *, struct configdef *,
                                        unsigned int *));
 
