@@ -2,18 +2,18 @@
 **  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-filter.h,v 1.65 2007/05/23 18:16:02 msk Exp $
+**  $Id: dkim-filter.h,v 1.71 2007/06/26 16:26:46 msk Exp $
 */
 
 #ifndef _DKIM_FILTER_H_
 #define _DKIM_FILTER_H_
 
 #ifndef lint
-static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.65 2007/05/23 18:16:02 msk Exp $";
+static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.71 2007/06/26 16:26:46 msk Exp $";
 #endif /* !lint */
 
 #define	DKIMF_PRODUCT	"Sendmail DKIM Filter"
-#define	DKIMF_VERSION	"1.0.0"
+#define	DKIMF_VERSION	"1.2.0"
 
 /* libsm */
 #include <sm/gen.h>
@@ -32,7 +32,7 @@ static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.65 2007/05/23 18:16
 /* defaults, limits, etc. */
 #define	BUFRSZ		256
 #define	CBINTERVAL	3
-#define CMDLINEOPTS	"a:Ab:c:C:d:DfFhi:I:k:Klm:M:o:p:P:qrRs:S:T:u:U:Vx:"
+#define CMDLINEOPTS	"a:Ab:c:C:d:DfFhi:I:k:KlL:m:M:o:p:P:qrRs:S:T:u:U:Vx:?"
 #define	DEFTIMEOUT	5
 #define	HOSTUNKNOWN	"unknown-host"
 #define	JOBIDUNKNOWN	"(unknown-jobid)"
