@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.8 2007/03/01 18:34:31 msk Exp $";
+static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.18 2007/05/21 22:19:33 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -30,8 +30,12 @@ static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.8 2007/03/01 18:34:31 m
 /* libdkim includes */
 #include "dkim-types.h"
 #include "dkim-keys.h"
+#include "dkim-cache.h"
 #include "dkim.h"
 
+/* prototypes */
+extern void dkim_error __P((DKIM *, const char *, ...));
+
 /* limits, macros, etc. */
 #define	BUFRSZ			1025
 
@@ -46,8 +50,6 @@ static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.8 2007/03/01 18:34:31 m
 # define RES_UNC_T		unsigned char *
 #endif /* __RES && __RES >= 19940415 */
 
-/* ========================= PRIVATE SECTION ========================= */
-
 /*
 **  DKIM_GET_KEY_DNS -- retrieve a DKIM key from DNS
 **
@@ -63,6 +65,10 @@ static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.8 2007/03/01 18:34:31 m
 DKIM_STAT
 dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 {
+#ifdef _FFR_QUERY_CACHE
+	bool cached = FALSE;
+	int ttl = 0;
+#endif /* _FFR_QUERY_CACHE */
 	int status;
 	int qdcount;
 	int ancount;
@@ -78,6 +84,7 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 	AR_LIB ar;
 	AR_QUERY q;
 #endif /* USE_ARLIB */
+	DKIM_LIB *lib;
 	unsigned char *p;
 	unsigned char *cp;
 	unsigned char *eom;
@@ -94,9 +101,31 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 	assert(dkim->dkim_domain != NULL);
 	assert(dkim->dkim_querymethod == DKIM_QUERY_DNS);
 
+	lib = dkim->dkim_libhandle;
+
 	snprintf(qname, sizeof qname - 1, "%s.%s.%s", dkim->dkim_selector,
 	         DKIM_DNSKEYNAME, dkim->dkim_domain);
 
+#ifdef _FFR_QUERY_CACHE
+	/* see if we have this data already cached */
+	if (dkim->dkim_libhandle->dkiml_cache != NULL)
+	{
+		int err = 0;
+		size_t blen = buflen;
+
+		dkim->dkim_cache_queries++;
+
+		status = dkim_cache_query(dkim->dkim_libhandle->dkiml_cache,
+		                          qname, 0, buf, &blen, &err);
+		if (status == 0)
+		{
+			dkim->dkim_cache_hits++;
+			return DKIM_STAT_OK;
+		}
+		/* XXX -- do something with errors here */
+	}
+#endif /* _FFR_QUERY_CACHE */
+
 #if USE_ARLIB
 	ar = dkim->dkim_libhandle->dkiml_arlib;
 
@@ -107,10 +136,12 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 	                sizeof ansbuf, &error,
 	                dkim->dkim_timeout == 0 ? NULL : &timeout);
 	if (q == NULL)
+	{
+		dkim_error(dkim, "ar_addquery() for `%s' failed", qname);
 		return DKIM_STAT_INTERNAL;
+	}
 
-# if _FFR_SET_DNS_CALLBACK
-	if (dkim->dkim_dns_callback == NULL)
+	if (lib->dkiml_dns_callback == NULL)
 	{
 		status = ar_waitreply(ar, q, NULL, NULL);
 	}
@@ -118,7 +149,7 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 	{
 		for (;;)
 		{
-			timeout.tv_sec = dkim->dkim_callback_int;
+			timeout.tv_sec = lib->dkiml_callback_int;
 			timeout.tv_usec = 0;
 
 			status = ar_waitreply(ar, q, NULL, &timeout);
@@ -126,12 +157,9 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 			if (status != AR_STAT_NOREPLY)
 				break;
 
-			dkim->dkim_dns_callback(dkim->dkim_user_context);
+			lib->dkiml_dns_callback(dkim->dkim_user_context);
 		}
 	}
-# else /* _FFR_SET_DNS_CALLBACK */
-	status = ar_waitreply(ar, q, NULL, NULL);
-# endif /* _FFR_SET_DNS_CALLBACK */
 
 	(void) ar_cancelquery(ar, q);
 #else /* USE_ARLIB */
@@ -140,7 +168,12 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 
 #if USE_ARLIB
 	if (status == AR_STAT_ERROR || status == AR_STAT_EXPIRED)
+	{
+		dkim_error(dkim, "ar_waitreply(): `%s' %s", qname,
+		           status == AR_STAT_ERROR ? "error"
+		                                   : "expired");
 		return DKIM_STAT_KEYFAIL;
+	}
 #else /* USE_ARLIB */
 	/*
 	**  A -1 return from res_query could mean a bunch of things,
@@ -159,6 +192,8 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 		  case TRY_AGAIN:
 		  case NO_RECOVERY:
 		  default:
+			dkim_error(dkim, "res_query(): `%s' %s",
+			           qname, hstrerror(h_errno));
 			return DKIM_STAT_KEYFAIL;
 		}
 	}
@@ -180,18 +215,27 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 		                 sizeof qname);
 
 		if ((n = dn_skipname(cp, eom)) < 0)
+		{
+			dkim_error(dkim, "`%s' reply corrupt", qname);
 			return DKIM_STAT_INTERNAL;
+		}
 		cp += n;
 
 		/* extract the type and class */
 		if (cp + INT16SZ + INT16SZ > eom)
+		{
+			dkim_error(dkim, "`%s' reply corrupt", qname);
 			return DKIM_STAT_INTERNAL;
+		}
 		GETSHORT(type, cp);
 		GETSHORT(class, cp);
 	}
 
 	if (type != T_TXT || class != C_IN)
+	{
+		dkim_error(dkim, "`%s' unexpected reply type/class", qname);
 		return DKIM_STAT_INTERNAL;
+	}
 
 	/* if NXDOMAIN, return DKIM_STAT_NOKEY */
 	if (hdr.rcode == NXDOMAIN)
@@ -204,7 +248,10 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 
 	/* if truncated, we can't do it */
 	if (hdr.tc)
+	{
+		dkim_error(dkim, "`%s' reply truncated", qname);
 		return DKIM_STAT_INTERNAL;
+	}
 
 	/*
 	**  Extract the data from the first answer.
@@ -213,27 +260,44 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 	/* grab the label, even though we know what we asked... */
 	if ((n = dn_expand((unsigned char *) &ansbuf, eom, cp,
 	                   (RES_UNC_T) qname, sizeof qname)) < 0)
+	{
+		dkim_error(dkim, "`%s' reply corrupt", qname);
 		return DKIM_STAT_INTERNAL;
+	}
 	/* ...and move past it */
 	cp += n;
 
 	/* extract the type and class */
 	if (cp + INT16SZ + INT16SZ > eom)
+	{
+		dkim_error(dkim, "`%s' reply corrupt", qname);
 		return DKIM_STAT_INTERNAL;
+	}
 	GETSHORT(type, cp);
 	GETSHORT(class, cp);
 
+#ifdef _FFR_QUERY_CACHE
+	/* get the TTL */
+	GETLONG(ttl, cp);
+#else /* _FFR_QUERY_CACHE */
 	/* skip the TTL */
 	cp += INT32SZ;
+#endif /* _FFR_QUERY_CACHE */
 
 	/* get payload length */
 	if (cp + INT16SZ > eom)
+	{
+		dkim_error(dkim, "`%s' reply corrupt", qname);
 		return DKIM_STAT_INTERNAL;
+	}
 	GETSHORT(n, cp);
 
 	/* XXX -- maybe deal with a partial reply rather than require it all */
 	if (cp + n > eom)
+	{
+		dkim_error(dkim, "`%s' reply corrupt", qname);
 		return DKIM_STAT_SYNTAX;
+	}
 
 	/* extract the payload */
 	memset(buf, '\0', buflen);
@@ -251,10 +315,21 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 		}
 	}
 
+#ifdef _FFR_QUERY_CACHE
+	if (!cached && buf[0] != '\0' &&
+	    dkim->dkim_libhandle->dkiml_cache != NULL)
+	{
+		int err = 0;
+
+		status = dkim_cache_insert(dkim->dkim_libhandle->dkiml_cache,
+		                           qname, buf, ttl, &err);
+		/* XXX -- do something with errors here */
+	}
+#endif /* _FFR_QUERY_CACHE */
+
 	return DKIM_STAT_OK;
 }
 
-#if DKIM_QUERY_FILE
 /*
 **  DKIM_GET_KEY_FILE -- retrieve a DKIM key from a text file (for testing)
 **
@@ -272,7 +347,7 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 **  	so will cause this function to return DKIM_STAT_KEYFAIL every time.
 **  	The file should contain lines of the form:
 ** 
-**  		selector@domain <space> key-data
+**  		<selector>._domainkey.<domain> <space> key-data
 **
 **  	Case matching on the left is case-sensitive, but libdkim already
 **  	wraps the domain name to lowercase.
@@ -284,6 +359,7 @@ dkim_get_key_file(DKIM *dkim, u_char *buf, size_t buflen)
 	FILE *f;
 	char *p;
 	char *p2;
+	char *path;
 	char name[BUFRSZ + 1];
 
 	assert(dkim != NULL);
@@ -291,7 +367,7 @@ dkim_get_key_file(DKIM *dkim, u_char *buf, size_t buflen)
 	assert(dkim->dkim_domain != NULL);
 	assert(dkim->dkim_querymethod == DKIM_QUERY_FILE);
 
-	path = dkim->dkim_libhandle->dkimf_queryinfo;
+	path = dkim->dkim_libhandle->dkiml_queryinfo;
 	if (path[0] == '\0')
 	{
 		dkim_error(dkim, "query file not defined");
@@ -305,8 +381,8 @@ dkim_get_key_file(DKIM *dkim, u_char *buf, size_t buflen)
 		return DKIM_STAT_KEYFAIL;
 	}
 
-	snprintf(name, sizeof name, "%s@%s", dkim->dkim_selector,
-	         dkim->dkim_domain);
+	snprintf(name, sizeof name, "%s.%s.%s", dkim->dkim_selector,
+	         DKIM_DNSKEYNAME, dkim->dkim_domain);
 
 	memset(buf, '\0', sizeof buf);
 	while (fgets(buf, BUFRSZ, f) != NULL)
@@ -343,4 +419,3 @@ dkim_get_key_file(DKIM *dkim, u_char *buf, size_t buflen)
 
 	return DKIM_STAT_NOKEY;
 }
-#endif /* DKIM_QUERY_FILE */
