@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.5 2007/05/21 22:19:33 msk Exp $";
+static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.6 2007/06/25 20:24:47 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -121,16 +121,8 @@ dkim_get_policy_file(DKIM *dkim, unsigned char *buf, size_t buflen)
 	{
 		/* set up the key for the lookup */
 		memset(qname, '\0', sizeof qname);
-#ifdef _FFR_ALLMAN_SSP_02
-		if (dkim->dkim_userpolicy)
-		{
-			snprintf(qname, sizeof qname, "%s.%s", dkim->dkim_user,
-			         DKIM_DNSUSERPOLICYNAME);
-		}
-#else /* _FFR_ALLMAN_SSP_02 */
 		snprintf(qname, sizeof qname, "%s.%s", DKIM_DNSPOLICYNAME,
 		         DKIM_DNSKEYNAME);
-#endif /* _FFR_ALLMAN_SSP_02 */
 
 		for (c = first + n; c < MAXLABELS; c++)
 		{
@@ -274,16 +266,8 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *buf, size_t buflen)
 	{
 		/* send the NS query */
 		memset(qname, '\0', sizeof qname);
-#ifdef _FFR_ALLMAN_SSP_02
-		if (dkim->dkim_userpolicy)
-		{
-			snprintf(qname, sizeof qname, "%s.%s", dkim->dkim_user,
-			         DKIM_DNSUSERPOLICYNAME);
-		}
-#else /* _FFR_ALLMAN_SSP_02 */
 		snprintf(qname, sizeof qname, "%s.%s", DKIM_DNSPOLICYNAME,
 		         DKIM_DNSKEYNAME);
-#endif /* _FFR_ALLMAN_SSP_02 */
 
 		for (c = first + n; c < MAXLABELS; c++)
 		{
@@ -316,15 +300,9 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *buf, size_t buflen)
 		timeout.tv_sec = dkim->dkim_timeout;
 		timeout.tv_usec = 0;
 
-# ifdef _FFR_ALLMAN_SSP_02
-		q = ar_addquery(ar, qname, C_IN, T_DKIMP, MAXCNAMEDEPTH,
-		                ansbuf, sizeof ansbuf, &arerror,
-		                dkim->dkim_timeout == 0 ? NULL : &timeout);
-# else /* _FFR_ALLMAN_SSP_02 */
 		q = ar_addquery(ar, qname, C_IN, T_TXT, MAXCNAMEDEPTH, ansbuf,
 		                sizeof ansbuf, &arerror,
 		                dkim->dkim_timeout == 0 ? NULL : &timeout);
-# endif /* _FFR_ALLMAN_SSP_02 */
 		if (q == NULL)
 		{
 			dkim_error(dkim, "ar_addquery() failed for `%s'",
@@ -355,12 +333,7 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *buf, size_t buflen)
 		(void) ar_cancelquery(ar, q);
 #else /* USE_ARLIB */
 
-# ifdef _FFR_ALLMAN_SSP_02
-		status = res_query(qname, C_IN, T_DKIMP, ansbuf,
-		                   sizeof ansbuf);
-# else /* _FFR_ALLMAN_SSP_02 */
 		status = res_query(qname, C_IN, T_TXT, ansbuf, sizeof ansbuf);
-# endif /* _FFR_ALLMAN_SSP_02 */
 
 #endif /* USE_ARLIB */
 
