@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.18 2007/05/23 01:02:50 msk Exp $";
+static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.19 2007/06/25 20:24:47 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -35,59 +35,31 @@ static struct chartable prv_keyparams[] =	/* key parameters */
 };
 struct chartable *keyparams = prv_keyparams;
 
-#ifdef _FFR_ALLMAN_SSP_02
-
-static struct chartable prv_policyparams[] =	/* policy parameters */
+static struct chartable prv_pflags[] =		/* policy flags */
 {
-	{ 'p',		DKIM_PPARAM_POLICY },
-	{ 'r',		DKIM_PPARAM_REPORTADDR },
-	{ 't',		DKIM_PPARAM_FLAGS },
-	{ 'u',		DKIM_PPARAM_USERQUERY },
+	{ 'y',		DKIM_PFLAG_TEST },
+	{ 's',		DKIM_PFLAG_NOSUBDOMAIN },
 	{ '\0',		-1 }
 };
+struct chartable *pflags = prv_pflags;
 
-#else /* _FFR_ALLMAN_SSP_02 */
-
-static struct chartable prv_policyparams[] =	/* policy parameters */
+static struct nametable prv_policyparams[] =	/* policy parameters */
 {
-	{ 'f',		DKIM_PPARAM_FLAGS },
-	{ 'n',		DKIM_PPARAM_NOTES },
-	{ 'o',		DKIM_PPARAM_POLICY },
-	{ 'r',		DKIM_PPARAM_REPORTADDR },
-	{ 'u',		DKIM_PPARAM_URI },
-	{ '\0',		-1 }
+	{ "dkim",	DKIM_PPARAM_POLICY },
+	{ "t",		DKIM_PPARAM_FLAGS },
+	{ NULL,		-1 }
 };
-
-#endif /* _FFR_ALLMAN_SSP_02 */
-
-struct chartable *policyparams = prv_policyparams;
-
-#ifdef _FFR_ALLMAN_SSP_02
+struct nametable *policyparams = prv_policyparams;
 
 static struct nametable prv_policies[] =	/* policies */
 {
 	{ "unknown",	DKIM_POLICY_UNKNOWN },
 	{ "all",	DKIM_POLICY_ALL },
 	{ "strict",	DKIM_POLICY_STRICT },
-	{ '\0',		-1 }
+	{ NULL,		-1 }
 };
 struct nametable *policies = prv_policies;
 
-#else /* _FFR_ALLMAN_SSP_02 */
-
-static struct chartable prv_policies[] =	/* policies */
-{
-	{ '~',		DKIM_POLICY_SIGNSOME },
-	{ '-',		DKIM_POLICY_REQUIRED },
-	{ '!',		DKIM_POLICY_AUTHORITY },
-	{ '.',		DKIM_POLICY_NEVER },
-	{ '^',		DKIM_POLICY_USER },
-	{ '\0',		-1 }
-};
-struct chartable *policies = prv_policies;
-
-#endif /* _FFR_ALLMAN_SSP_02 */
-
 static struct nametable prv_sigparams[] =	/* signature parameters */
 {
 	{ "a",		DKIM_PARAM_SIGNALG },
