@@ -7,7 +7,7 @@
 #define _DKIM_TABLES_H_
 
 #ifndef lint
-static char dkim_tables_h_id[] = "@(#)$Id: dkim-tables.h,v 1.6 2007/02/27 19:25:41 msk Exp $";
+static char dkim_tables_h_id[] = "@(#)$Id: dkim-tables.h,v 1.7 2007/06/25 20:24:47 msk Exp $";
 #endif /* !lint */
 
 /* structures */
@@ -25,18 +25,14 @@ struct chartable
 
 /* tables */
 struct chartable *keyparams;
-struct chartable *policyparams;
-
-#ifdef _FFR_ALLMAN_SSP_02
-struct nametable *policies;
-#else /* _FFR_ALLMAN_SSP_02 */
-struct chartable *policies;
-#endif /* _FFR_ALLMAN_SSP_02 */
+struct chartable *pflags;
 
 struct nametable *algorithms;
 struct nametable *canonicalizations;
 struct nametable *hashes;
 struct nametable *keytypes;
+struct nametable *policies;
+struct nametable *policyparams;
 struct nametable *querytypes;
 struct nametable *results;
 struct nametable *settypes;
