@@ -7,7 +7,7 @@
 #define _DKIM_TYPES_H_
 
 #ifndef lint
-static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.60 2007/05/21 22:19:33 msk Exp $";
+static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.61 2007/06/25 20:30:19 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -118,9 +118,6 @@ struct dkim
 	bool			dkim_blankline;
 	bool			dkim_subdomain;
 	bool			dkim_skipbody;
-#ifdef _FFR_ALLMAN_SSP_02
-	bool			dkim_userpolicy;
-#endif /* _FFR_ALLMAN_SSP_02 */
 	int			dkim_signum;
 	int			dkim_mode;
 	int			dkim_state;
