@@ -7,7 +7,7 @@
 #define _DKIM_H_
 
 #ifndef lint
-static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.98 2007/05/23 01:02:50 msk Exp $";
+static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.106 2007/06/26 16:28:53 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -31,7 +31,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.98 2007/05/23 01:02:50 msk Exp $"
 **  	pp == patch number
 */
 
-#define	DKIM_LIB_VERSION	0x01000000
+#define	DKIM_LIB_VERSION	0x01020000
 
 /* the basics */
 #ifndef NULL
@@ -61,7 +61,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.98 2007/05/23 01:02:50 msk Exp $"
 #define MAXHEADER		4096	/* buffer for caching one header */
 #define MAXHEADERS		32768	/* buffer for caching headers */
 #define MAXLABELS		16	/* max. labels we allow */
-#define MAXPOLICYDEPTH		5	/* policy recursion we allow */
+#define MAXPOLICYDEPTH		1	/* policy recursion we allow */
 #define MAXTAGNAME		8	/* biggest tag name */
 
 /* defaults */
@@ -84,12 +84,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.98 2007/05/23 01:02:50 msk Exp $"
 /* special DNS tokens */
 #define	DKIM_DNSKEYNAME		"_domainkey"
 					/* reserved DNS sub-zone */
-#define	DKIM_DNSPOLICYNAME	"_policy"
-					/* reserved DNS sub-zone */
-#ifdef _FFR_ALLMAN_SSP_02
-# define DKIM_DNSUSERPOLICYNAME	"_user"
-					/* reserved DNS sub-zone */
-#endif /* _FFR_ALLMAN_SSP_02 */
+#define	DKIM_DNSPOLICYNAME	"_ssp"	/* reserved DNS sub-zone */
 
 /*
 **  DKIM_VERSION -- version; attempts to support backward compatibility
@@ -124,6 +119,7 @@ typedef int DKIM_STAT;
 #define	DKIM_STAT_KEYFAIL	11	/* key retrieval failed */
 #define	DKIM_STAT_CBREJECT	12	/* callback requested reject */
 #define	DKIM_STAT_CBINVALID	13	/* callback gave invalid result */
+#define	DKIM_STAT_CBTRYAGAIN	14	/* callback says try again later */
 
 /*
 **  DKIM_CBSTAT -- callback status code type
@@ -133,6 +129,7 @@ typedef int DKIM_CBSTAT;
 
 #define	DKIM_CBSTAT_CONTINUE	0	/* continue */
 #define	DKIM_CBSTAT_REJECT	1	/* reject */
+#define	DKIM_CBSTAT_TRYAGAIN	2	/* try again later */
 
 /*
 **  DKIM_CANON -- canonicalization method
@@ -218,22 +215,9 @@ typedef int dkim_key_t;
 
 typedef int dkim_pparam_t;
 
-#ifdef _FFR_ALLMAN_SSP_02
-
-# define DKIM_PPARAM_POLICY	0	/* p */
-# define DKIM_PPARAM_REPORTADDR	1	/* r */
-# define DKIM_PPARAM_FLAGS	2	/* t */
-# define DKIM_PPARAM_USERQUERY	3	/* u */
-
-#else /* _FFR_ALLMAN_SSP_02 */
-
-# define DKIM_PPARAM_POLICY	0	/* o */
-# define DKIM_PPARAM_FLAGS	1	/* f */
-# define DKIM_PPARAM_NOTES	2	/* n */
-# define DKIM_PPARAM_REPORTADDR	3	/* r */
-# define DKIM_PPARAM_URI	4	/* u */
-
-#endif /* _FFR_ALLMAN_SSP_02 */
+# define DKIM_PPARAM_POLICY	0	/* dkim */
+# define DKIM_PPARAM_FLAGS	1	/* t */
+# define DKIM_PPARAM_REPORTADDR	2	/* r */
 
 /*
 **  DKIM_POLICY -- policies
@@ -241,27 +225,21 @@ typedef int dkim_pparam_t;
 
 typedef int dkim_policy_t;
 
-#ifdef _FFR_ALLMAN_SSP_02
+#define DKIM_POLICY_UNKNOWN	0	/* unknown */
+#define DKIM_POLICY_ALL		1	/* all */
+#define DKIM_POLICY_STRICT	2	/* strict */
 
-# define DKIM_POLICY_UNKNOWN	0	/* unknown */
-# define DKIM_POLICY_ALL	1	/* all */
-# define DKIM_POLICY_STRICT	2	/* strict */
+#define DKIM_POLICY_DEFAULT	DKIM_POLICY_UNKNOWN
+#define DKIM_POLICY_DEFAULTTXT	"dkim=unknown"
 
-# define DKIM_POLICY_DEFAULT	DKIM_POLICY_UNKNOWN
-# define DKIM_POLICY_DEFAULTTXT	"p=unknown; u=no"
+/*
+**  DKIM_PFLAG -- policy flags
+*/
 
-#else /* _FFR_ALLMAN_SSP_02 */
+#define	DKIM_PFLAG_TEST		0x01	/* t */
+#define	DKIM_PFLAG_NOSUBDOMAIN	0x02	/* s */
 
-# define DKIM_POLICY_SIGNSOME	0	/* ~ */
-# define DKIM_POLICY_REQUIRED	1	/* - */
-# define DKIM_POLICY_AUTHORITY	2	/* ! */
-# define DKIM_POLICY_NEVER	3	/* . */
-# define DKIM_POLICY_USER	4	/* ^ */
-
-# define DKIM_POLICY_DEFAULT	DKIM_POLICY_SIGNSOME
-# define DKIM_POLICY_DEFAULTTXT	"o=~"
-
-#endif /* _FFR_ALLMAN_SSP_02 */
+#define DKIM_PFLAG_DEFAULT	0x00
 
 /*
 **  DKIM_SETTYPE -- types of sets
@@ -706,7 +684,7 @@ extern DKIM_STAT dkim_getcanons __P((DKIM *dkim, dkim_canon_t *hdr,
 **
 **  Parameters:
 **  	dkim -- DKIM handle
-**  	when -- timestamp on the signature (returned)
+**  	ver -- signature version (returned)
 **
 **  Return value:
 **  	A DKIM_STAT value.
