@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.10 2006/09/13 19:14:55 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.11 2007/05/12 14:41:39 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -272,3 +272,53 @@ dkim_lowerhdr(unsigned char *str)
 			*p = tolower(*p);
 	}
 }
+
+/*
+**  DKIM_HEXCHAR -- translate a hexadecimal character
+**  
+**  Parameters:
+**  	c -- character to translate
+**
+**  Return value:
+**  	Decimal equivalent.
+*/
+
+int
+dkim_hexchar(int c)
+{
+	switch (c)
+	{
+	  case '0':
+	  case '1':
+	  case '2':
+	  case '3':
+	  case '4':
+	  case '5':
+	  case '6':
+	  case '7':
+	  case '8':
+	  case '9':
+		return c - '0';
+
+	  case 'A':
+	  case 'B':
+	  case 'C':
+	  case 'D':
+	  case 'E':
+	  case 'F':
+		return 10 + c - 'A';
+
+	  case 'a':
+	  case 'b':
+	  case 'c':
+	  case 'd':
+	  case 'e':
+	  case 'f':
+		return 10 + c - 'a';
+
+	  default:
+		assert(0);
+	}
+
+	/* NOTREACHED */
+}
